# Работа с пользовательскими полями

Yandex Tracker позволяет работать с нестандартным набором полей.
Мы учли это и добавили возможность передавать в запросах ожидаемую вами модель.

Допустим, у вас есть очередь для службы поддержки (назовём её HELP). Для ведения такой очереди вам
могут потребоваться дополнительные поля, например для сохранения идентификатора внешней системы
или каких-либо ещё пользовательских данных.

О том, как настроить локальное поле, вы можете узнать из соответствующего раздела документации:
https://cloud.yandex.ru/docs/tracker/local-fields

В нашем примере мы рассмотрим добавление двух полей:
- `userUsername`
- `userId`

### Создаём модель задачи

Создайте дочерний класс задачи из `yatracker`, чтобы насытить родительский класс нужными полями:

```python
from yatracker.types import FullIssue

class HelpIssue(FullIssue, kw_only=True):
    user_username: str | None = None
    user_id: int
```

Обратите внимание, что модели нашей библиотеки автоматически используют со стороны python имена в
стиле `snake_case`, а при работе с Tracker, они конвертируются в `camelCase` – как это принято в
самом трекере.


#### Локальные поля очереди

В случае с локальными полями очередей трекера, их названия выглядят вот так:
```txt
64a51c6d866ea82411abe756--userId
```

Работать с таким именем неудобно, не говоря о неудобствах передачи его в kwargs.
Авторы стандартной библиотеки предлагают делать это так:

```python
issue.update(**{'64a51c6d866ea82411abe756--userId': 42})
```

Мы же предлагаем использовать удобные вам названия, а наша библиотека позаботится о правильном
преобразовании:

```python
from yatracker.types import FullIssue, field

class HelpIssue(FullIssue, kw_only=True):
    user_id: int = field(name="64a51c6d866ea82411abe756--userId")
```

### Используем модель задачи

Для работы с кастомными моделями мы предусмотрели параметр `_type`, позволяющий корректно
распознавать набор атрибутов и работать с ними в удобном для вас формате.

```python
issue = await tracker.create_issue(
    summary="New Issue",
    queue="HELP",
    user_id=42,
    _type=HelpIssue,
)

print(issue.user_id)
```
